# frozen_string_literal: true

module HyraxHelper
  include ::BlacklightHelper
  include Hyrax::BlacklightOverride
  include Hyrax::HyraxHelperBehavior

  def available_translations
    {
      'de' => 'Deutsch',
      'en' => 'English',
      'es' => 'Español',
      'fr' => 'Français',
      'it' => 'Italiano',
      'pt-BR' => 'Português do Brasil',
      'zh' => '中文'
    }.slice(RDMS::Application.config.i18n.available_locales )
  end

  def s3_file_download_url_for_file_set(file_set_id)
    s3 = S3StorageService.new
    s3.init_client

    file_set = FileSet.find(file_set_id)
    bucket_name = s3.sanitise_name(file_set.parent_works.first.id)
    bucket = Aws::S3::Resource.new(region: ENV['S3_REGION']).bucket(bucket_name)

    begin
      latest_version_uri = file_set.latest_content_version.uri
      file_key = "/#{file_set_id}/files/#{latest_version_uri.split('/')[-3]}/#{file_set.title.first}"
    rescue StandardError
      begin
        latest_version_uri = file_set.files[0]
        file_key = "/#{file_set_id}/files/#{latest_version_uri.split('/')[-1]}/#{file_set.title.first}"
      rescue StandardError
        return nil
      end
    end
    url_options = {
      expires_in: 60.minutes.seconds.to_i,
      response_content_disposition: "attachment; filename=\"#{file_key}\""
    }

    object = bucket.object(file_key)
    object.exists? ? object.presigned_url(:get, url_options).to_s : nil
  end

  def can_create_work_in_group?(group_id)
    current_user.admin? || current_user.crc_manager_for?(group_id) || current_user.group_manager_for?(group_id) || current_user.group_member_for?(group_id)
  end

  def can_manage_managers_for_group?(presenter)
    current_user.admin? || current_user.crc_manager_for?(presenter.id)
  end

  def can_manage_members_for_group?(presenter)
    current_user.admin? || current_user.crc_manager_for?(presenter.id) || current_user.group_manager_for?(presenter.id)
  end

  def manager_role(presenter)
    Collection.find(presenter.id).manager_role
  end

  def member_role(presenter)
    Collection.find(presenter.id).member_role
  end

  def manager_role_for_group(presenter)
    Collection.find(presenter.id).manager_role_for_group
  end

  def member_role_for_group(presenter)
    Collection.find(presenter.id).member_role_for_group
  end

  def within_file_size_threshold?(presenter)
    work = ActiveFedora::Base.find(presenter.id)
    total_size = work.total_file_size
    total_size > 0 && total_size < ENV.fetch('DOWNLOAD_SIZE_LIMIT', '100000000').to_i
  end
end
